@@ -23,6 +23,8 @@
 
 class Mixer;
 
+#include "kmix_debug.h"
+
 #include <qxml.h>
 #include <QColor>
 #include <QTextStream>
@@ -34,8 +36,6 @@ class Mixer;
 #include <vector>
 #include <ostream>
 
-#include <KDebug>
-
 struct SortedStringComparator
 {
     bool operator()(const std::string&, const std::string&) const;
@@ -132,7 +132,7 @@ static GuiVisibility const GuiNEVER;   // e.g. templates with regexp's
 		if (string == GuiNEVER.id)
 			return GuiNEVER;
 
-		kWarning() << "Unknown GuiVisibility=" << string << ". Applying default=" << GuiFULL.id;
+		qCWarning(KMIX_LOG) << "Unknown GuiVisibility=" << string << ". Applying default=" << GuiFULL.id;
 		return GuiFULL;
 	}
 
@@ -308,9 +308,9 @@ public:
     // Enumeration for the scope
     enum ProfileScope { NONE, SOUNDCARD };
     
-    bool startDocument();
-    bool startElement( const QString&, const QString&, const QString& , const QXmlAttributes& );
-    bool endElement( const QString&, const QString&, const QString& );
+    bool startDocument() Q_DECL_OVERRIDE;
+    bool startElement( const QString&, const QString&, const QString& , const QXmlAttributes& ) Q_DECL_OVERRIDE;
+    bool endElement( const QString&, const QString&, const QString& ) Q_DECL_OVERRIDE;
     
 private:
     void addControl(const QXmlAttributes& attributes);
